{ config, pkgs, lib, ... }:

let
  cfg = config.theming.dock;
in
{
  options.theming.dock = {
    enable = lib.mkOption {
      default = false;
      type = lib.types.bool;
    };
    autostart = lib.mkOption {
      default = false;
      type = lib.types.bool;
    };
  };

  config = {
    home.pointerCursor = {
      x11.enable = true;
      name = "Bibata-Modern-Classic";
      package = pkgs.bibata-cursors;
      gtk.enable = true;
      size = 20;
    };

    gtk = {
      enable = true;
      cursorTheme = {
        name = "Bibata-Modern-Classic";
        package = pkgs.bibata-cursors;
        size = 20;
      };
      iconTheme = {
        name = "Papirus-Dark";
        package = pkgs.papirus-icon-theme;
      };
      gtk3 = {
        extraConfig.gtk-application-prefer-dark-theme = true;
      };
      gtk4 = {
        extraConfig.gtk-application-prefer-dark-theme = true;
      };
    };

    qt = {
      enable = true;
      platformTheme.name = "gtk";
      style.name = "adwaita-dark";
    };

    home.sessionVariables = {
      "GTK_THEME" = "Adwaita:dark";
    };

    home.packages = lib.mkIf cfg.enable [
      pkgs.plank pkgs.libwnck pkgs.bamf
    ];

    xdg.autostart = lib.mkIf cfg.autostart {
      enable = true;
      entries = [
        "${pkgs.plank}/share/applications/plank.desktop"
      ];
    };
  };
}
